package lab;

import java.io.IOException;
import java.util.List;

import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.scene.control.Button;
import javafx.scene.control.TableColumn;
import javafx.scene.control.TableView;
import javafx.scene.control.TextField;
import javafx.scene.control.ToggleButton;
import javafx.scene.control.ToggleGroup;
import javafx.scene.control.cell.PropertyValueFactory;

/**
 * 
 */
public class MainScreenController {

    @FXML
    private Button btnGenerateScore;

    @FXML
    private Button btnLoadAll;

    @FXML
    private Button btnLoadFirstTen;

	@FXML
    private TableView<Score> scores;

	@FXML
    private TableColumn<Score, String> nickColumn;

    @FXML
    private TableColumn<Score, Integer> pointsColumn;

	@FXML
	private ToggleGroup difficult;

    @FXML
    private ToggleButton easy;

    @FXML
    private ToggleButton hard;

    @FXML
    private ToggleButton medium;

    @FXML
	private TextField name;

	private App app;
	
	@FXML
	void play(ActionEvent event) throws IOException {
		Difficult dif = (Difficult)difficult.getSelectedToggle().getProperties().get(Difficult.class);
		app.switchToGame(name.getText(), dif.getNumberOfMonsters());
	}
	
	public void setApp(App app) {
		this.app = app;
	}

    @FXML
    void btnGenerateScoreAction(ActionEvent event) {
    	Score score = Score.generate();
    	this.scores.getItems().add(score);
    	DbConnector.insertScore(score);
    }

    @FXML
    void btnLoadAllAction(ActionEvent event) {
    	updateScoreTable(DbConnector.getAll());
    }

    @FXML
    void btnLoadFirstTenAction(ActionEvent event) {
    	updateScoreTable(DbConnector.getFirstTen());
    }
    
    private void updateScoreTable(List<Score> scores) {
    	this.scores.getItems().clear();
    	this.scores.getItems().addAll(scores);
    }
    
    @FXML
	void initialize() {
		assert difficult != null : "fx:id=\"difficult\" was not injected: check your FXML file 'mainScreen.fxml'.";
		assert name != null : "fx:id=\"name\" was not injected: check your FXML file 'mainScreen.fxml'.";
		easy.getProperties().put(Difficult.class, Difficult.EASY);
		medium.getProperties().put(Difficult.class, Difficult.MEDIUM);
		hard.getProperties().put(Difficult.class, Difficult.HARD);

		nickColumn.setCellValueFactory(new PropertyValueFactory<>("name"));
		pointsColumn.setCellValueFactory(new PropertyValueFactory<>("points"));
		
		initDB();
	}
	
	private void initDB() {
		//Stream.generate(Score::generate).limit(10).toList();
		DbConnector.createTable();
		scores.getItems().addAll(DbConnector.getAll());
	}

}
